==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/jsonstore.js <==
joo.classLoader.prepare("package ext.config",/* {*/

/**
 * Small helper class to make creating <a href="Ext.data.Store.html">Ext.data.Store</a>s from JSON data easier. A JsonStore will be automatically configured with a <a href="Ext.data.JsonReader.html">Ext.data.JsonReader</a>.
 <p>A store configuration would be something like:</p><pre><code>var store = new Ext.data.JsonStore({
 // store configs
 autoDestroy: true,
 url: 'get-images.php',
 storeId: 'myStore',
 // reader configs
 root: 'images',
 idProperty: 'name',
 fields: ['name', 'url', {name:'size', type: 'float'}, {name:'lastmod', type:'date'}]
 });
 </code></pre><br/><br/> <p>This store is configured to consume a returned object of the form:</p><pre><code>{
 images: [
 {name: 'Image one', url:'/GetImage.php?id=1', size:46.5, lastmod: new Date(2007, 10, 29)},
 {name: 'Image Two', url:'/GetImage.php?id=2', size:43.2, lastmod: new Date(2007, 10, 30)}
 ]
 }
 </code></pre>An object literal of this form could also be used as the <a href="output/Ext.data.JsonStore.html#Ext.data.JsonStore-data">data</a> config option.<br/><br/> <p><b>&#42;Note:</b> Although not listed here, this class accepts all of the configuration options of <b><a href="Ext.data.JsonReader.html">JsonReader</a></b>.</p>
 *
 * <p>This class represents the xtype 'jsonstore' and serves as a
 * typed config object for constructor of class JsonStore.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.data.JsonStore
 */
{ExtConfig:{target:"ext.data.JsonStore", xtype:"jsonstore"}},
"public class jsonstore extends ext.config.store",4,function($$private){;return[ 

  "public function jsonstore",function jsonstore$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    ext.config.store.call(this,config);
  },


];},[],["ext.config.store"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/jsonstore.js <==
joo.classLoader.prepare("package ext.config",/* {*/

/**
 * Small helper class to make creating <a href="Ext.data.Store.html">Ext.data.Store</a>s from JSON data easier. A JsonStore will be automatically configured with a <a href="Ext.data.JsonReader.html">Ext.data.JsonReader</a>.
 <p>A store configuration would be something like:</p><pre><code>var store = new Ext.data.JsonStore({
 // store configs
 autoDestroy: true,
 url: 'get-images.php',
 storeId: 'myStore',
 // reader configs
 root: 'images',
 idProperty: 'name',
 fields: ['name', 'url', {name:'size', type: 'float'}, {name:'lastmod', type:'date'}]
 });
 </code></pre><br/><br/> <p>This store is configured to consume a returned object of the form:</p><pre><code>{
 images: [
 {name: 'Image one', url:'/GetImage.php?id=1', size:46.5, lastmod: new Date(2007, 10, 29)},
 {name: 'Image Two', url:'/GetImage.php?id=2', size:43.2, lastmod: new Date(2007, 10, 30)}
 ]
 }
 </code></pre>An object literal of this form could also be used as the <a href="output/Ext.data.JsonStore.html#Ext.data.JsonStore-data">data</a> config option.<br/><br/> <p><b>&#42;Note:</b> Although not listed here, this class accepts all of the configuration options of <b><a href="Ext.data.JsonReader.html">JsonReader</a></b>.</p>
 *
 * <p>This class serves as a typed config object for constructor of class JsonStore.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.data.JsonStore
 */
{ExtConfig:{target:"ext.data.JsonStore"}},
"public class jsonstore extends ext.config.store",4,function($$private){var $1=ext.config;return[ 

  "public function jsonstore",function jsonstore(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.store.call(this,config);
  },


undefined];},[],["ext.config.store"], "0.8.0", "0.9.12"
);
